@@ -1,12 +1,16 @@
-from metaflow import FlowSpec, step, Config, Parameter
+from metaflow import step, Config, Parameter
+from obproject import ProjectFlow
+import os
 
 
-class ConfigOverrideTestFlow(FlowSpec):
+class ConfigOverrideTestFlow(ProjectFlow):
 
-    base_config = Config("config", default="config.json")
+    base_config = Config(
+        "config", default=os.path.join(os.path.dirname(__file__), "config.json")
+    )
     lr = Parameter(
         name="lr",
-        default=None,
+        default=0.001,
         type=float,
         help="Override for the lr value in config.json's train_args.",
         required=False,
